@@ -25,7 +25,8 @@ use List::MoreUtils qw{ any };
 use Tie::IxHash;
 use Clone qw/clone/;
 use HTML::Packer;
-use JSON qw{ to_json };
+use JSON qw{ to_json from_json };
+use Try::Tiny;
 
 =head1 NAME
 
@@ -139,9 +140,8 @@ sub definition {
                 defaultValue    => 1,
             },
             parser => {
-                noFormPost      => 1,
-                fieldType       => 'selectBox',
-                defaultValue    => [$session->config->get("defaultTemplateParser")],
+                fieldType    => 'templateParser',
+                defaultValue => $session->config->get('defaultTemplateParser'),
             },	
             namespace => {
                 fieldType       => 'combo',
@@ -212,7 +212,7 @@ copy.
 
 sub duplicate {
 	my $self = shift;
-	my $newTemplate = $self->SUPER::duplicate;
+	my $newTemplate = $self->SUPER::duplicate(@_);
     $newTemplate->update({isDefault => 0});
     if ( my $storageId = $self->get('storageIdExample') ) {
         my $newStorage  = WebGUI::Storage->get( $self->session, $storageId )->copy;
@@ -284,98 +284,162 @@ Returns the TabForm object that will be used in generating the edit page for thi
 
 sub getEditForm {
 	my $self = shift;
+	my $session = $self->session;
+
+	my ( $db, $url, $style, $form, $config )
+	    = $session->quick(qw( db url style form config ));
+
 	my $tabform = $self->SUPER::getEditForm();
-	my $i18n = WebGUI::International->new($self->session, 'Asset_Template');
+	my $i18n = WebGUI::International->new($session, 'Asset_Template');
+
+	my ( $properties, $meta, $display ) =
+	    map { $tabform->getTab($_) } qw( properties meta display );
+
+	my $returnUrl = $form->get('returnUrl');
 	$tabform->hidden({
 		name=>"returnUrl",
-		value=>$self->session->form->get("returnUrl")
+		value=>$returnUrl,
 		});
 	if ($self->getValue("namespace") eq "") {
-		my $namespaces = $self->session->dbSlave->buildHashRef("select distinct(namespace) from template order by namespace");
-		$tabform->getTab("properties")->combo(
+		my $namespaces = $db->buildHashRef("select distinct(namespace) from template order by namespace");
+		$properties->combo(
 			-name=>"namespace",
 			-options=>$namespaces,
 			-label=>$i18n->get('namespace'),
 			-hoverHelp=>$i18n->get('namespace description'),
-			-value=>[$self->session->form->get("namespace")] 
+			-value=>[$form->get("namespace")]
 			);
 	} else {
-		$tabform->getTab("meta")->readOnly(
+		$meta->readOnly(
 			-label=>$i18n->get('namespace'),
 			-hoverHelp=>$i18n->get('namespace description'),
 			-value=>$self->getValue("namespace")
-			);	
-		$tabform->getTab("meta")->hidden(
+			);
+		$meta->hidden(
 			-name=>"namespace",
 			-value=>$self->getValue("namespace")
 			);
 	}
-	$tabform->getTab("display")->yesNo(
+	$display->yesNo(
 		-name=>"showInForms",
 		-value=>$self->getValue("showInForms"),
 		-label=>$i18n->get('show in forms'),
 		-hoverHelp=>$i18n->get('show in forms description'),
 		);
-	$tabform->getTab("properties")->codearea(
+	$properties->codearea(
 		-name=>"template",
 		-label=>$i18n->get('assetName'),
 		-hoverHelp=>$i18n->get('template description'),
 		-syntax => "html",
 		-value=>$self->getValue("template")
 		);
-    $tabform->getTab('properties')->yesNo(
-        name        => "usePacked",
-        label       => $i18n->get('usePacked label'),
-        hoverHelp   => $i18n->get('usePacked description'),
-        value       => $self->getValue("usePacked"),
-    );
-	if($self->session->config->get("templateParsers")){
-		my @temparray = @{$self->session->config->get("templateParsers")};
-		tie my %parsers, 'Tie::IxHash';
-		while(my $a = shift @temparray){
-			$parsers{$a} = $self->getParser($self->session, $a)->getName();
-		}
-		my $value = [$self->getValue("parser")];
-		$value = \[$self->session->config->get("defaultTemplateParser")] if(!$self->getValue("parser"));
-		$tabform->getTab("properties")->selectBox(
-			-name=>"parser",
-			-options=>\%parsers,
-			-value=>$value,
-			-label=>$i18n->get('parser'),
-			-hoverHelp=>$i18n->get('parser description'),
-			);
-	}
+	$properties->raw(qq(
+	    <tr>
+	        <td class='formDescription' valign='top'>
+	            ${\ $i18n->get('Preview') }
+	        </td>
+	        <td class='tableData'>
+	            <input type='button'
+	                   value='${\ $i18n->get('Preview') }'
+	                   id='preview'/>
+	            <input type='button'
+	                   value='${\ $i18n->get('Configure') }'
+	                   id='previewConfig'/>
+	        </td>
+	    </tr>
+	));
+	my $cform = WebGUI::HTMLForm->new($session);
+	$cform->yesNo(
+	    id        => 'previewRaw',
+	    name      => 'previewRaw',
+	    label     => $i18n->get('Plain Text?'),
+	    hoverHelp => $i18n->get('Plain Text hoverHelp'),
+	);
+	$cform->text(
+	    id           => 'previewFetchUrl',
+	    label        => $i18n->get('URL'),
+	    hoverHelp    => $i18n->get('URL hoverHelp'),
+	    defaultValue => $returnUrl,
+	);
+	$cform->button(
+	    id        => 'previewFetch',
+	    label     => $i18n->get('Fetch Variables'),
+	    hoverHelp => $i18n->get('Fetch Variables hoverHelp'),
+	    value     => $i18n->get('Fetch'),
+	);
+	$cform->codearea(
+	    id        => 'previewVars',
+	    label     => $i18n->get('Variables'),
+	    hoverHelp => $i18n->get('Variables hoverHelp'),
+	);
 
-    $tabform->getTab('properties')->jsonTable(
-        name        => 'attachmentsJson', 
-        value       => $self->get('attachmentsJson'),
-        label       => $i18n->get("attachment display label"),
-        fields      => [
-            {
-                type            => "text",
-                name            => "url",
-                label           => $i18n->get('attachment header url'),
-                size            => '48',
-            },
-            {
-                type            => "select",
-                name            => "type",
-                label           => $i18n->get('attachment header type'),
-                options         => [
-                    stylesheet => $i18n->get('css label'),
-                    headScript => $i18n->get('js head label'),
-                    bodyScript => $i18n->get('js body label'),
-                ],
-            },
-        ],
-    );
+	$cform->hidden(id => 'previewId', value => $self->getId);
+	$cform->hidden(id => 'previewGateway', value => $url->gateway);
+	$properties->raw(qq(
+	    <tr>
+	    <td></td>
+	    <td>
+	        <div id='previewConfigForm'>
+	            <div class='hd'>${\ $i18n->get('Configure Preview') }</div>
+	            <table class='bd'>${\ $cform->printRowsOnly }</table>
+	            <div class='ft' style='margin:0 auto; text-align: center'>
+	                <button id='previewConfigClose'>Close</button>
+	            </div>
+	        </div>
+	    </td>
+	    </tr>
+	));
 
-        $tabform->getTab('properties')->image( 
-            name        => 'storageIdExample',
-            value       => $self->getValue('storageIdExample'),
-            label       => $i18n->get('field storageIdExample'),
-            hoverHelp   => $i18n->get('field storageIdExample description'),
-        );
+	$properties->yesNo(
+	    name        => "usePacked",
+	    label       => $i18n->get('usePacked label'),
+	    hoverHelp   => $i18n->get('usePacked description'),
+	    value       => $self->getValue("usePacked"),
+	);
+
+	$style->setScript($url->extras($_)) for qw(
+	    yui/build/json/json-min.js
+	    yui/build/container/container-min.js
+	    templatePreview.js
+	);
+
+	$properties->templateParser(
+		name      => 'parser',
+		label     => $i18n->get('parser'),
+		hoverHelp => $i18n->get('parser description'),
+		value     => $self->getValue('parser'),
+	);
+
+	$properties->jsonTable(
+	    name        => 'attachmentsJson',
+	    value       => $self->get('attachmentsJson'),
+	    label       => $i18n->get("attachment display label"),
+	    fields      => [
+	        {
+	            type            => "text",
+	            name            => "url",
+	            label           => $i18n->get('attachment header url'),
+	            size            => '48',
+	        },
+	        {
+	            type            => "select",
+	            name            => "type",
+	            label           => $i18n->get('attachment header type'),
+	            options         => [
+	                stylesheet => $i18n->get('css label'),
+	                headScript => $i18n->get('js head label'),
+	                bodyScript => $i18n->get('js body label'),
+	            ],
+	        },
+	    ],
+	);
+
+	$properties->image(
+	    name        => 'storageIdExample',
+	    value       => $self->getValue('storageIdExample'),
+	    label       => $i18n->get('field storageIdExample'),
+	    hoverHelp   => $i18n->get('field storageIdExample description'),
+	);
 
 	return $tabform;
 }
@@ -482,6 +546,22 @@ sub getParser {
     return $parser->new($session);
 }
 
+#-------------------------------------------------------------------
+#
+# See the warning about using this on processVariableHeaders(). If no
+# variables were captured, we'll return the empty string.
+
+sub getVariableJson {
+    my ($class, $session) = @_;
+    my ($show, $vars, $json);
+
+    return ($show = $session->stow->get('showTemplateVars'))
+        && ($vars = $show->{vars})
+        && ($json = eval { JSON::encode_json($vars) })
+        && ($show->{startDelimiter} . $json . $show->{endDelimiter})
+        or '';
+}
+
 #-------------------------------------------------------------------
 
 =head2 importAssetCollateralData ( data )
@@ -497,6 +577,7 @@ sub importAssetCollateralData {
     }
     return $self->SUPER::importAssetCollateralData( $data, @args );
 }
+
     
 #-------------------------------------------------------------------
 
@@ -565,15 +646,15 @@ sub prepare {
 
 	$style->setRawHeadTags($headBlock);
 
+    my %props = ( type => 'text/css', rel => 'stylesheet' );
 	foreach my $sheet ( @{ $self->getAttachments('stylesheet') } ) {
-		my %props = ( type => 'text/css', rel => 'stylesheet' );
 		$style->setLink($sheet->{url}, \%props);
 	}
 
 	my $doScripts = sub {
 		my ($type, $body) = @_;
+        my %props = ( type => 'text/javascript' );
 		foreach my $script ( @{ $self->getAttachments($type) } ) {
-			my %props = ( type => 'text/javascript' );
 			$style->setScript($script->{url}, \%props, $body);
 		}
 	};
@@ -623,6 +704,15 @@ sub process {
        return to_json( $vars );
     }
 
+    my $stow = $session->stow;
+    my $show = $stow->get('showTemplateVars');
+    if ( $show && $show->{assetId} eq $self->getId && $self->canEdit ) {
+        # This will never be true again, cause we're getting rid of assetId
+        delete $show->{assetId};
+        $show->{vars} = $vars;
+        $stow->set( showTemplateVars => $show );
+    }
+
 	$self->prepare unless ($self->{_prepared});
     my $parser      = $self->getParser($session, $self->get("parser"));
     my $template    = $self->get('usePacked')
@@ -639,6 +729,58 @@ sub process {
 	return $output;
 }
 
+#-------------------------------------------------------------------
+
+# Used for debugging and the template test renderer.
+
+# WARNING: Please do not rely on this behavior. It's a bit of a hack, and
+# should not be considered part of the core API. Eventually, we will have
+# introspectable template objects so that you can more easily (and
+# efficiently) get this kind of information.
+
+# If the first value for the 'X-Webgui-Template-Variables' header is our
+# assetId, then in addition to processing the template, append add a json
+# representation of our template variables to the response. The headers
+# "X-Webgui-Template-Variables-Start" and "X-Webgui-Template-Variables-End"
+# will contain the delimiters for the start and end of this content so that
+# the user agent (who had to have stuck the header in in the first place) can
+# parse it out.  The delimiters will make the whole thing look like an xml
+# comment (<!-- ... -->) just in case.
+
+# We would just send the vars in the header, but different webservers have
+# different limits on header field size and it's impossible to say whether our
+# data will fit inside them or not.
+
+# This is intended to be called earlier in the request cycle (in the Content
+# URL handler) so that the headers get sent before any chunked content starts
+# being set up.  We set the stow here and check it during process() to see
+# whether we need to include the delimited json. Later on, Content will call
+# call getVariableJson to get the results.
+
+{
+    my $head = 'X-Webgui-Template-Variables';
+    my @chr  = ('0'..'9', 'a'..'z', 'A'..'Z');
+
+    sub processVariableHeaders {
+        my ($class, $session) = @_;
+        my $r = $session->request;
+        if (my $id = $r->headers_in->{$head}) {
+            my $rnd = join('', map { $chr[int(rand($#chr))] } (1..32));
+            my $out = $r->headers_out;
+            my $st  = "<!-- $rnd ";
+            my $end = " $rnd -->";
+            $out->{"$head-Start"} = $st;
+            $out->{"$head-End"}   = $end;
+            $session->stow->set(
+                showTemplateVars => {
+                    assetId        => $id,
+                    startDelimiter => $st,
+                    endDelimiter   => $end,
+                }
+            );
+        }
+    }
+}
 
 #-------------------------------------------------------------------
 
@@ -1174,6 +1316,42 @@ sub www_styleWizard {
 
 #-------------------------------------------------------------------
 
+=head2 www_preview
+
+Rendes this template with the given variables (posted as JSON)
+
+=cut
+
+sub www_preview {
+    my $self    = shift;
+    my $session = $self->session;
+    return $session->privilege->insufficient unless $self->canEdit;
+
+    my $form = $session->form;
+    my $http = $session->http;
+
+    try {
+        my $output = $self->processRaw(
+            $session,
+            $form->get('template'),
+            from_json($form->get('variables')),
+            $form->get('parser'),
+        );
+        if ($form->get('plainText')) {
+            $http->setMimeType('text/plain');
+        }
+        elsif ($output !~ /<html>/) {
+            $output = $session->style->userStyle($output);
+        }
+        return $output;
+    } catch {
+        $http->setMimeType('text/plain');
+        $_[0];
+    }
+}
+
+#-------------------------------------------------------------------
+
 =head2 www_view 
 
 Override the default behavior.  When a template is viewed, it redirects you
