@@ -1,5 +1,6 @@
 function initWGContextMenus() {
     var menus = YAHOO.util.Dom.getElementsByClassName('wg-contextmenu');
+    var max_loop = 15;
     for (var i = menus.length; i--; ) {
         var menu = menus[i];
         if (menu.initialized) {
@@ -16,6 +17,11 @@ function initWGContextMenus() {
             menu.align("tl", "bl");
             menu.show();
         }, myMenu);
+        max_loop--;
+        if (max_loop == 0) {
+            window.setTimeout(initWGContextMenus, 50);
+            break;
+        }
     }
 }
 YAHOO.util.Event.onDOMReady(initWGContextMenus);
